@@ -122,6 +122,8 @@ func TestOrganizationsCreate(t *testing.T) {
 
 		assert.Equal(t, *options.Name, org.Name)
 		assert.Equal(t, *options.Email, org.Email)
+		assert.Equal(t, "remote", org.DefaultExecutionMode)
+		assert.Nil(t, org.DefaultAgentPool)
 	})
 
 	t.Run("when no email is provided", func(t *testing.T) {
@@ -195,13 +197,27 @@ func TestOrganizationsRead(t *testing.T) {
 		require.NotNil(t, org.DefaultProject)
 		assert.NotNil(t, org.DefaultProject.Name)
 	})
+
+	t.Run("with default execution mode of 'agent'", func(t *testing.T) {
+		orgAgentTest, orgAgentTestCleanup := createOrganizationWithDefaultAgentPool(t, client)
+		org, err := client.Organizations.Read(ctx, orgAgentTest.Name)
+
+		t.Cleanup(orgAgentTestCleanup)
+		require.NoError(t, err)
+
+		t.Run("execution mode and agent pool are properly decoded", func(t *testing.T) {
+			assert.Equal(t, "agent", org.DefaultExecutionMode)
+			assert.NotNil(t, org.DefaultAgentPool)
+			assert.Equal(t, org.DefaultAgentPool.ID, orgAgentTest.DefaultAgentPool.ID)
+		})
+	})
 }
 
 func TestOrganizationsUpdate(t *testing.T) {
 	client := testClient(t)
 	ctx := context.Background()
 
-	t.Run("with TFC-only options", func(t *testing.T) {
+	t.Run("with HCP Terraform-only options", func(t *testing.T) {
 		skipIfEnterprise(t)
 
 		orgTest, orgTestCleanup := createOrganization(t, client)
@@ -217,14 +233,33 @@ func TestOrganizationsUpdate(t *testing.T) {
 		assert.Equal(t, false, org.SendPassingStatusesForUntriggeredSpeculativePlans)
 	})
 
+	t.Run("with new AggregatedCommitStatusEnabled option", func(t *testing.T) {
+		skipIfEnterprise(t)
+
+		for _, testCase := range []bool{true, false} {
+			orgTest, orgTestCleanup := createOrganization(t, client)
+			t.Cleanup(orgTestCleanup)
+
+			options := OrganizationUpdateOptions{
+				AggregatedCommitStatusEnabled: Bool(testCase),
+			}
+
+			org, err := client.Organizations.Update(ctx, orgTest.Name, options)
+			require.NoError(t, err)
+
+			assert.Equal(t, testCase, org.AggregatedCommitStatusEnabled)
+		}
+	})
+
 	t.Run("with valid options", func(t *testing.T) {
 		orgTest, orgTestCleanup := createOrganization(t, client)
 
 		options := OrganizationUpdateOptions{
-			Name:            String(randomString(t)),
-			Email:           String(randomString(t) + "@tfe.local"),
-			SessionTimeout:  Int(3600),
-			SessionRemember: Int(3600),
+			Name:                 String(randomString(t)),
+			Email:                String(randomString(t) + "@tfe.local"),
+			SessionTimeout:       Int(3600),
+			SessionRemember:      Int(3600),
+			DefaultExecutionMode: String("local"),
 		}
 
 		org, err := client.Organizations.Update(ctx, orgTest.Name, options)
@@ -254,6 +289,7 @@ func TestOrganizationsUpdate(t *testing.T) {
 			assert.Equal(t, *options.Email, item.Email)
 			assert.Equal(t, *options.SessionTimeout, item.SessionTimeout)
 			assert.Equal(t, *options.SessionRemember, item.SessionRemember)
+			assert.Equal(t, *options.DefaultExecutionMode, item.DefaultExecutionMode)
 		}
 	})
 
@@ -263,6 +299,20 @@ func TestOrganizationsUpdate(t *testing.T) {
 		assert.EqualError(t, err, ErrInvalidOrg.Error())
 	})
 
+	t.Run("with agent pool provided, but remote execution mode", func(t *testing.T) {
+		orgTest, orgTestCleanup := createOrganization(t, client)
+		t.Cleanup(orgTestCleanup)
+
+		pool, agentPoolCleanup := createAgentPool(t, client, orgTest)
+		t.Cleanup(agentPoolCleanup)
+
+		org, err := client.Organizations.Update(ctx, orgTest.Name, OrganizationUpdateOptions{
+			DefaultAgentPool: pool,
+		})
+		assert.Nil(t, org)
+		assert.ErrorContains(t, err, "Default agent pool must not be specified unless using 'agent' execution mode")
+	})
+
 	t.Run("when only updating a subset of fields", func(t *testing.T) {
 		orgTest, orgTestCleanup := createOrganization(t, client)
 		t.Cleanup(orgTestCleanup)
@@ -272,6 +322,32 @@ func TestOrganizationsUpdate(t *testing.T) {
 		assert.Equal(t, orgTest.Name, org.Name)
 		assert.Equal(t, orgTest.Email, org.Email)
 	})
+
+	t.Run("with different default execution modes", func(t *testing.T) {
+		// this helper creates an organization and then updates it to use a default agent pool, so it implicitly asserts
+		// that the organization's execution mode can be updated from 'remote' -> 'agent'
+		org, orgAgentTestCleanup := createOrganizationWithDefaultAgentPool(t, client)
+		assert.Equal(t, "agent", org.DefaultExecutionMode)
+		assert.NotNil(t, org.DefaultAgentPool)
+
+		// assert that organization's execution mode can be updated from 'agent' -> 'remote'
+		org, err := client.Organizations.Update(ctx, org.Name, OrganizationUpdateOptions{
+			DefaultExecutionMode: String("remote"),
+		})
+		require.NoError(t, err)
+		assert.Equal(t, "remote", org.DefaultExecutionMode)
+		assert.Nil(t, org.DefaultAgentPool)
+
+		// assert that organization's execution mode can be updated from 'remote' -> 'local'
+		org, err = client.Organizations.Update(ctx, org.Name, OrganizationUpdateOptions{
+			DefaultExecutionMode: String("local"),
+		})
+		require.NoError(t, err)
+		assert.Equal(t, "local", org.DefaultExecutionMode)
+		assert.Nil(t, org.DefaultAgentPool)
+
+		t.Cleanup(orgAgentTestCleanup)
+	})
 }
 
 func TestOrganizationsDelete(t *testing.T) {
@@ -596,6 +672,111 @@ func TestOrganizationsAllowForceDeleteSetting(t *testing.T) {
 	})
 }
 
+func TestOrganization_DataRetentionPolicy(t *testing.T) {
+	skipUnlessEnterprise(t)
+
+	client := testClient(t)
+	ctx := context.Background()
+
+	orgTest, orgTestCleanup := createOrganization(t, client)
+	t.Cleanup(orgTestCleanup)
+
+	organization, err := client.Organizations.Read(ctx, orgTest.Name)
+	require.NoError(t, err)
+	require.Nil(t, organization.DataRetentionPolicy)
+	require.Nil(t, organization.DataRetentionPolicyChoice)
+
+	dataRetentionPolicy, err := client.Organizations.ReadDataRetentionPolicyChoice(ctx, orgTest.Name)
+	require.NoError(t, err)
+	require.Nil(t, dataRetentionPolicy)
+
+	t.Run("set and update data retention policy to delete older", func(t *testing.T) {
+		createdDataRetentionPolicy, err := client.Organizations.SetDataRetentionPolicyDeleteOlder(ctx, orgTest.Name, DataRetentionPolicyDeleteOlderSetOptions{DeleteOlderThanNDays: 33})
+		require.NoError(t, err)
+		require.Equal(t, 33, createdDataRetentionPolicy.DeleteOlderThanNDays)
+		require.Contains(t, createdDataRetentionPolicy.ID, "drp-")
+
+		dataRetentionPolicy, err = client.Organizations.ReadDataRetentionPolicyChoice(ctx, orgTest.Name)
+		require.NoError(t, err)
+		require.NotNil(t, dataRetentionPolicy.DataRetentionPolicyDeleteOlder)
+
+		require.Equal(t, 33, dataRetentionPolicy.DataRetentionPolicyDeleteOlder.DeleteOlderThanNDays)
+		require.Equal(t, createdDataRetentionPolicy.ID, dataRetentionPolicy.DataRetentionPolicyDeleteOlder.ID)
+		require.Contains(t, dataRetentionPolicy.DataRetentionPolicyDeleteOlder.ID, "drp-")
+
+		organization, err := client.Organizations.Read(ctx, orgTest.Name)
+		require.NoError(t, err)
+		require.Equal(t, dataRetentionPolicy.DataRetentionPolicyDeleteOlder.ID, organization.DataRetentionPolicyChoice.DataRetentionPolicyDeleteOlder.ID)
+
+		// deprecated DataRetentionPolicy field should also have been populated
+		require.NotNil(t, organization.DataRetentionPolicy)
+		require.Equal(t, organization.DataRetentionPolicy.ID, dataRetentionPolicy.DataRetentionPolicyDeleteOlder.ID)
+
+		// try updating the number of days
+		createdDataRetentionPolicy, err = client.Organizations.SetDataRetentionPolicyDeleteOlder(ctx, orgTest.Name, DataRetentionPolicyDeleteOlderSetOptions{DeleteOlderThanNDays: 1})
+		require.NoError(t, err)
+		require.Equal(t, 1, createdDataRetentionPolicy.DeleteOlderThanNDays)
+
+		dataRetentionPolicy, err = client.Organizations.ReadDataRetentionPolicyChoice(ctx, orgTest.Name)
+		require.NoError(t, err)
+		require.NotNil(t, dataRetentionPolicy.DataRetentionPolicyDeleteOlder)
+		require.Equal(t, 1, dataRetentionPolicy.DataRetentionPolicyDeleteOlder.DeleteOlderThanNDays)
+		require.Equal(t, createdDataRetentionPolicy.ID, dataRetentionPolicy.DataRetentionPolicyDeleteOlder.ID)
+	})
+
+	t.Run("set data retention policy to not delete", func(t *testing.T) {
+		createdDataRetentionPolicy, err := client.Organizations.SetDataRetentionPolicyDontDelete(ctx, orgTest.Name, DataRetentionPolicyDontDeleteSetOptions{})
+		require.NoError(t, err)
+		require.Contains(t, createdDataRetentionPolicy.ID, "drp-")
+
+		dataRetentionPolicy, err = client.Organizations.ReadDataRetentionPolicyChoice(ctx, orgTest.Name)
+		require.NoError(t, err)
+		require.NotNil(t, dataRetentionPolicy.DataRetentionPolicyDontDelete)
+		require.Equal(t, createdDataRetentionPolicy.ID, dataRetentionPolicy.DataRetentionPolicyDontDelete.ID)
+
+		// dont delete policies should leave the legacy DataRetentionPolicy field on organizations empty
+		organization, err := client.Organizations.Read(ctx, orgTest.Name)
+		require.NoError(t, err)
+		require.Nil(t, organization.DataRetentionPolicy)
+	})
+
+	t.Run("change data retention policy type", func(t *testing.T) {
+		_, err = client.Organizations.SetDataRetentionPolicyDeleteOlder(ctx, orgTest.Name, DataRetentionPolicyDeleteOlderSetOptions{DeleteOlderThanNDays: 45})
+		require.NoError(t, err)
+
+		dataRetentionPolicy, err = client.Organizations.ReadDataRetentionPolicyChoice(ctx, orgTest.Name)
+		require.NoError(t, err)
+		require.NotNil(t, dataRetentionPolicy.DataRetentionPolicyDeleteOlder)
+		require.Equal(t, 45, dataRetentionPolicy.DataRetentionPolicyDeleteOlder.DeleteOlderThanNDays)
+		require.Nil(t, dataRetentionPolicy.DataRetentionPolicyDontDelete)
+
+		_, err = client.Organizations.SetDataRetentionPolicyDontDelete(ctx, orgTest.Name, DataRetentionPolicyDontDeleteSetOptions{})
+		require.NoError(t, err)
+		dataRetentionPolicy, err = client.Organizations.ReadDataRetentionPolicyChoice(ctx, orgTest.Name)
+		require.NoError(t, err)
+		require.Nil(t, dataRetentionPolicy.DataRetentionPolicyDeleteOlder)
+		require.NotNil(t, dataRetentionPolicy.DataRetentionPolicyDontDelete)
+
+		_, err = client.Organizations.SetDataRetentionPolicyDeleteOlder(ctx, orgTest.Name, DataRetentionPolicyDeleteOlderSetOptions{DeleteOlderThanNDays: 20})
+		require.NoError(t, err)
+
+		dataRetentionPolicy, err = client.Organizations.ReadDataRetentionPolicyChoice(ctx, orgTest.Name)
+		require.NoError(t, err)
+		require.NotNil(t, dataRetentionPolicy.DataRetentionPolicyDeleteOlder)
+		require.Equal(t, 20, dataRetentionPolicy.DataRetentionPolicyDeleteOlder.DeleteOlderThanNDays)
+		require.Nil(t, dataRetentionPolicy.DataRetentionPolicyDontDelete)
+	})
+
+	t.Run("delete data retention policy", func(t *testing.T) {
+		err = client.Organizations.DeleteDataRetentionPolicy(ctx, orgTest.Name)
+		require.NoError(t, err)
+
+		dataRetentionPolicy, err = client.Organizations.ReadDataRetentionPolicyChoice(ctx, orgTest.Name)
+		assert.Nil(t, err)
+		require.Nil(t, dataRetentionPolicy)
+	})
+}
+
 func orgItemsContainsName(items []*Organization, name string) bool {
 	hasName := false
 	for _, item := range items {
