@@ -44,6 +44,8 @@ func TestWorkspacesList(t *testing.T) {
 	t.Cleanup(wTest1Cleanup)
 	wTest2, wTest2Cleanup := createWorkspace(t, client, orgTest)
 	t.Cleanup(wTest2Cleanup)
+	wTest3, wTest3Cleanup := createWorkspace(t, client, orgTest)
+	t.Cleanup(wTest3Cleanup)
 
 	t.Run("without list options", func(t *testing.T) {
 		wl, err := client.Workspaces.List(ctx, orgTest.Name, nil)
@@ -51,7 +53,7 @@ func TestWorkspacesList(t *testing.T) {
 		assert.Contains(t, wl.Items, wTest1)
 		assert.Contains(t, wl.Items, wTest2)
 		assert.Equal(t, 1, wl.CurrentPage)
-		assert.Equal(t, 2, wl.TotalCount)
+		assert.Equal(t, 3, wl.TotalCount)
 	})
 
 	t.Run("with list options", func(t *testing.T) {
@@ -67,7 +69,35 @@ func TestWorkspacesList(t *testing.T) {
 		require.NoError(t, err)
 		assert.Empty(t, wl.Items)
 		assert.Equal(t, 999, wl.CurrentPage)
-		assert.Equal(t, 2, wl.TotalCount)
+		assert.Equal(t, 3, wl.TotalCount)
+	})
+
+	t.Run("when sorting by workspace names", func(t *testing.T) {
+		wl, err := client.Workspaces.List(ctx, orgTest.Name, &WorkspaceListOptions{
+			Sort: "name",
+		})
+		require.NoError(t, err)
+		require.NotEmpty(t, wl.Items)
+		require.GreaterOrEqual(t, len(wl.Items), 2)
+		assert.Equal(t, wl.Items[0].Name < wl.Items[1].Name, true)
+	})
+
+	t.Run("when sorting workspaces on current-run.created-at", func(t *testing.T) {
+		_, unappliedCleanup1 := createRunUnapplied(t, client, wTest2)
+		t.Cleanup(unappliedCleanup1)
+
+		_, unappliedCleanup2 := createRunUnapplied(t, client, wTest3)
+		t.Cleanup(unappliedCleanup2)
+
+		wl, err := client.Workspaces.List(ctx, orgTest.Name, &WorkspaceListOptions{
+			Include: []WSIncludeOpt{WSCurrentRun},
+			Sort:    "current-run.created-at",
+		})
+
+		require.NoError(t, err)
+		require.NotEmpty(t, wl.Items)
+		require.GreaterOrEqual(t, len(wl.Items), 2)
+		assert.True(t, wl.Items[1].CurrentRun.CreatedAt.After(wl.Items[0].CurrentRun.CreatedAt))
 	})
 
 	t.Run("when searching a known workspace", func(t *testing.T) {
@@ -108,7 +138,7 @@ func TestWorkspacesList(t *testing.T) {
 	})
 
 	t.Run("when searching using exclude-tags", func(t *testing.T) {
-		for wsID, tag := range map[string]string{wTest1.ID: "foo", wTest2.ID: "bar"} {
+		for wsID, tag := range map[string]string{wTest1.ID: "foo", wTest2.ID: "bar", wTest3.ID: "foo"} {
 			err := client.Workspaces.AddTags(ctx, wsID, WorkspaceAddTagsOptions{
 				Tags: []*Tag{
 					{
@@ -506,11 +536,40 @@ func TestWorkspacesCreate(t *testing.T) {
 		}
 	})
 
+	t.Run("with valid auto-apply-run-trigger option", func(t *testing.T) {
+		skipIfEnterprise(t)
+		// FEATURE FLAG: auto-apply-run-trigger
+		// Once un-flagged, delete this test and add an AutoApplyRunTrigger field
+		// to the basic "with valid options" test below.
+
+		options := WorkspaceCreateOptions{
+			Name:                String(fmt.Sprintf("foo-%s", randomString(t))),
+			AutoApplyRunTrigger: Bool(true),
+		}
+
+		w, err := client.Workspaces.Create(ctx, orgTest.Name, options)
+		require.NoError(t, err)
+
+		// Get a refreshed view from the API.
+		refreshed, err := client.Workspaces.Read(ctx, orgTest.Name, *options.Name)
+		require.NoError(t, err)
+
+		for _, item := range []*Workspace{
+			w,
+			refreshed,
+		} {
+			assert.NotEmpty(t, item.ID)
+			assert.Equal(t, *options.Name, item.Name)
+			assert.Equal(t, *options.AutoApplyRunTrigger, item.AutoApplyRunTrigger)
+		}
+	})
+
 	t.Run("with valid options", func(t *testing.T) {
 		options := WorkspaceCreateOptions{
-			Name:                       String("foo"),
-			AllowDestroyPlan:           Bool(false),
+			Name:                       String(fmt.Sprintf("foo-%s", randomString(t))),
+			AllowDestroyPlan:           Bool(true),
 			AutoApply:                  Bool(true),
+			AutoDestroyAt:              NullableTime(time.Date(2025, 1, 1, 0, 0, 0, 0, time.UTC)),
 			Description:                String("qux"),
 			AssessmentsEnabled:         Bool(false),
 			FileTriggersEnabled:        Bool(true),
@@ -549,6 +608,7 @@ func TestWorkspacesCreate(t *testing.T) {
 			assert.Equal(t, *options.Description, item.Description)
 			assert.Equal(t, *options.AllowDestroyPlan, item.AllowDestroyPlan)
 			assert.Equal(t, *options.AutoApply, item.AutoApply)
+			assert.Equal(t, options.AutoDestroyAt, item.AutoDestroyAt)
 			assert.Equal(t, *options.AssessmentsEnabled, item.AssessmentsEnabled)
 			assert.Equal(t, *options.FileTriggersEnabled, item.FileTriggersEnabled)
 			assert.Equal(t, *options.Operations, item.Operations)
@@ -581,7 +641,7 @@ func TestWorkspacesCreate(t *testing.T) {
 
 	t.Run("when options has an invalid organization", func(t *testing.T) {
 		w, err := client.Workspaces.Create(ctx, badIdentifier, WorkspaceCreateOptions{
-			Name: String("foo"),
+			Name: String(fmt.Sprintf("foo-%s", randomString(t))),
 		})
 		assert.Nil(t, w)
 		assert.EqualError(t, err, ErrInvalidOrg.Error())
@@ -621,6 +681,32 @@ func TestWorkspacesCreate(t *testing.T) {
 		assert.Equal(t, err, ErrRequiredAgentPoolID)
 	})
 
+	t.Run("when no execution mode is specified, in an organization with local as default execution mode", func(t *testing.T) {
+		// Remove the below organization creation and use the one from the outer scope once the feature flag is removed
+		orgTest, orgTestCleanup := createOrganizationWithOptions(t, client, OrganizationCreateOptions{
+			Name:                 String("tst-" + randomString(t)[0:20] + "-ff-on"),
+			Email:                String(fmt.Sprintf("%s@tfe.local", randomString(t))),
+			DefaultExecutionMode: String("local"),
+		})
+		t.Cleanup(orgTestCleanup)
+
+		options := WorkspaceCreateOptions{
+			Name: String(fmt.Sprintf("foo-%s", randomString(t))),
+			SettingOverwrites: &WorkspaceSettingOverwritesOptions{
+				ExecutionMode: Bool(false),
+			},
+		}
+
+		_, err := client.Workspaces.Create(ctx, orgTest.Name, options)
+		require.NoError(t, err)
+
+		// Get a refreshed view from the API.
+		refreshed, err := client.Workspaces.Read(ctx, orgTest.Name, *options.Name)
+		require.NoError(t, err)
+
+		assert.Equal(t, "local", refreshed.ExecutionMode)
+	})
+
 	t.Run("when an error is returned from the API", func(t *testing.T) {
 		w, err := client.Workspaces.Create(ctx, "bar", WorkspaceCreateOptions{
 			Name:             String(fmt.Sprintf("bar-%s", randomString(t))),
@@ -692,6 +778,51 @@ func TestWorkspacesCreate(t *testing.T) {
 		require.NoError(t, err)
 		assert.Equal(t, options.TriggerPatterns, w.TriggerPatterns)
 	})
+
+	t.Run("when organization has a default execution mode", func(t *testing.T) {
+		defaultExecutionOrgTest, defaultExecutionOrgTestCleanup := createOrganizationWithDefaultAgentPool(t, client)
+		t.Cleanup(defaultExecutionOrgTestCleanup)
+
+		t.Run("with setting overwrites set to false, workspace inherits the default execution mode", func(t *testing.T) {
+			options := WorkspaceCreateOptions{
+				Name: String(fmt.Sprintf("tst-agent-cody-banks-%s", randomString(t))),
+				SettingOverwrites: &WorkspaceSettingOverwritesOptions{
+					ExecutionMode: Bool(false),
+					AgentPool:     Bool(false),
+				},
+			}
+			w, err := client.Workspaces.Create(ctx, defaultExecutionOrgTest.Name, options)
+
+			require.NoError(t, err)
+			assert.Equal(t, "agent", w.ExecutionMode)
+		})
+
+		t.Run("with setting overwrites set to true, workspace ignores the default execution mode", func(t *testing.T) {
+			options := WorkspaceCreateOptions{
+				Name:          String(fmt.Sprintf("tst-agent-tony-tanks-%s", randomString(t))),
+				ExecutionMode: String("local"),
+				SettingOverwrites: &WorkspaceSettingOverwritesOptions{
+					ExecutionMode: Bool(true),
+					AgentPool:     Bool(true),
+				},
+			}
+			w, err := client.Workspaces.Create(ctx, defaultExecutionOrgTest.Name, options)
+
+			require.NoError(t, err)
+			assert.Equal(t, "local", w.ExecutionMode)
+		})
+
+		t.Run("when explicitly setting execution mode, workspace ignores the default execution mode", func(t *testing.T) {
+			options := WorkspaceCreateOptions{
+				Name:          String(fmt.Sprintf("tst-remotely-interesting-workspace-%s", randomString(t))),
+				ExecutionMode: String("remote"),
+			}
+			w, err := client.Workspaces.Create(ctx, defaultExecutionOrgTest.Name, options)
+
+			require.NoError(t, err)
+			assert.Equal(t, "remote", w.ExecutionMode)
+		})
+	})
 }
 
 func TestWorkspacesRead(t *testing.T) {
@@ -713,6 +844,7 @@ func TestWorkspacesRead(t *testing.T) {
 		assert.NotEmpty(t, w.Actions)
 		assert.Equal(t, orgTest.Name, w.Organization.Name)
 		assert.NotEmpty(t, w.CreatedAt)
+		assert.NotEmpty(t, wTest.SettingOverwrites)
 	})
 
 	t.Run("links are properly decoded", func(t *testing.T) {
@@ -749,6 +881,33 @@ func TestWorkspacesRead(t *testing.T) {
 		assert.Nil(t, w)
 		assert.EqualError(t, err, ErrInvalidWorkspaceValue.Error())
 	})
+
+	t.Run("when workspace is inheriting the default execution mode", func(t *testing.T) {
+		defaultExecutionOrgTest, defaultExecutionOrgTestCleanup := createOrganizationWithDefaultAgentPool(t, client)
+		t.Cleanup(defaultExecutionOrgTestCleanup)
+
+		options := WorkspaceCreateOptions{
+			Name: String(fmt.Sprintf("tst-agent-cody-banks-%s", randomString(t))),
+			SettingOverwrites: &WorkspaceSettingOverwritesOptions{
+				ExecutionMode: Bool(false),
+				AgentPool:     Bool(false),
+			},
+		}
+
+		wDefaultTest, wDefaultTestCleanup := createWorkspaceWithOptions(t, client, defaultExecutionOrgTest, options)
+		t.Cleanup(wDefaultTestCleanup)
+
+		t.Run("and workspace execution mode is default", func(t *testing.T) {
+			w, err := client.Workspaces.Read(ctx, defaultExecutionOrgTest.Name, wDefaultTest.Name)
+			assert.NoError(t, err)
+			assert.NotEmpty(t, w)
+
+			assert.Equal(t, defaultExecutionOrgTest.DefaultExecutionMode, w.ExecutionMode)
+			assert.NotEmpty(t, w.SettingOverwrites)
+			assert.Equal(t, false, *w.SettingOverwrites.ExecutionMode)
+			assert.Equal(t, false, *w.SettingOverwrites.ExecutionMode)
+		})
+	})
 }
 
 func TestWorkspacesReadWithOptions(t *testing.T) {
@@ -764,7 +923,7 @@ func TestWorkspacesReadWithOptions(t *testing.T) {
 	svTest, svTestCleanup := createStateVersion(t, client, 0, wTest)
 	t.Cleanup(svTestCleanup)
 
-	// give TFC some time to process the statefile and extract the outputs.
+	// give HCP Terraform some time to process the statefile and extract the outputs.
 	waitForSVOutputs(t, client, svTest.ID)
 
 	t.Run("when options to include resource", func(t *testing.T) {
@@ -944,6 +1103,21 @@ func TestWorkspacesUpdate(t *testing.T) {
 		assert.Equal(t, wTest.WorkingDirectory, wAfter.WorkingDirectory)
 	})
 
+	t.Run("when updating auto-apply-run-trigger", func(t *testing.T) {
+		skipIfEnterprise(t)
+		// Feature flag: auto-apply-run-trigger. Once flag is removed, delete
+		// this test and add the attribute to one generic update test.
+		options := WorkspaceUpdateOptions{
+			AutoApplyRunTrigger: Bool(true),
+		}
+
+		wAfter, err := client.Workspaces.Update(ctx, orgTest.Name, wTest.Name, options)
+		require.NoError(t, err)
+
+		assert.Equal(t, wTest.Name, wAfter.Name)
+		assert.NotEqual(t, wTest.AutoApplyRunTrigger, wAfter.AutoApplyRunTrigger)
+	})
+
 	t.Run("when updating project", func(t *testing.T) {
 		skipUnlessBeta(t)
 
@@ -982,6 +1156,7 @@ func TestWorkspacesUpdate(t *testing.T) {
 			Name:                       String(randomString(t)),
 			AllowDestroyPlan:           Bool(true),
 			AutoApply:                  Bool(false),
+			AutoDestroyAt:              NullableTime(time.Date(2025, 1, 1, 0, 0, 0, 0, time.UTC)),
 			FileTriggersEnabled:        Bool(true),
 			Operations:                 Bool(false),
 			QueueAllRuns:               Bool(false),
@@ -1007,6 +1182,7 @@ func TestWorkspacesUpdate(t *testing.T) {
 			assert.Equal(t, *options.Name, item.Name)
 			assert.Equal(t, *options.AllowDestroyPlan, item.AllowDestroyPlan)
 			assert.Equal(t, *options.AutoApply, item.AutoApply)
+			assert.Equal(t, options.AutoDestroyAt, item.AutoDestroyAt)
 			assert.Equal(t, *options.FileTriggersEnabled, item.FileTriggersEnabled)
 			assert.Equal(t, *options.Description, item.Description)
 			assert.Equal(t, *options.Operations, item.Operations)
@@ -1441,6 +1617,54 @@ func TestWorkspacesUpdateByID(t *testing.T) {
 	})
 }
 
+func TestWorkspacesUpdateWithDefaultExecutionMode(t *testing.T) {
+	client := testClient(t)
+	ctx := context.Background()
+
+	defaultExecutionOrgTest, defaultExecutionOrgTestCleanup := createOrganizationWithDefaultAgentPool(t, client)
+	t.Cleanup(defaultExecutionOrgTestCleanup)
+
+	wTest, wCleanup := createWorkspace(t, client, defaultExecutionOrgTest)
+	t.Cleanup(wCleanup)
+
+	t.Run("when explicitly setting execution mode, workspace ignores the default execution mode", func(t *testing.T) {
+		options := WorkspaceUpdateOptions{
+			ExecutionMode: String("remote"),
+		}
+		w, err := client.Workspaces.Update(ctx, defaultExecutionOrgTest.Name, wTest.Name, options)
+
+		require.NoError(t, err)
+		assert.Equal(t, "remote", w.ExecutionMode)
+	})
+
+	t.Run("with setting overwrites set to true, workspace ignores the default execution mode", func(t *testing.T) {
+		options := WorkspaceUpdateOptions{
+			ExecutionMode: String("local"),
+			SettingOverwrites: &WorkspaceSettingOverwritesOptions{
+				ExecutionMode: Bool(true),
+				AgentPool:     Bool(true),
+			},
+		}
+		w, err := client.Workspaces.Update(ctx, defaultExecutionOrgTest.Name, wTest.Name, options)
+
+		require.NoError(t, err)
+		assert.Equal(t, "local", w.ExecutionMode)
+	})
+
+	t.Run("with setting overwrites set to false, workspace inherits the default execution mode", func(t *testing.T) {
+		options := WorkspaceUpdateOptions{
+			SettingOverwrites: &WorkspaceSettingOverwritesOptions{
+				ExecutionMode: Bool(false),
+				AgentPool:     Bool(false),
+			},
+		}
+		w, err := client.Workspaces.Update(ctx, defaultExecutionOrgTest.Name, wTest.Name, options)
+
+		require.NoError(t, err)
+		assert.Equal(t, "agent", w.ExecutionMode)
+	})
+}
+
 func TestWorkspacesDelete(t *testing.T) {
 	client := testClient(t)
 	ctx := context.Background()
@@ -1684,9 +1908,15 @@ func TestWorkspacesLock(t *testing.T) {
 	t.Cleanup(wTestCleanup)
 
 	t.Run("with valid options", func(t *testing.T) {
+		require.Empty(t, wTest.LockedBy)
+
 		w, err := client.Workspaces.Lock(ctx, wTest.ID, WorkspaceLockOptions{})
 		require.NoError(t, err)
 		assert.True(t, w.Locked)
+
+		require.NoError(t, err)
+		require.NotEmpty(t, w.LockedBy)
+		requireExactlyOneNotEmpty(t, w.LockedBy.Run, w.LockedBy.Team, w.LockedBy.User)
 	})
 
 	t.Run("when workspace is already locked", func(t *testing.T) {
@@ -2395,3 +2625,152 @@ func TestWorkspacesProjects(t *testing.T) {
 		}
 	})
 }
+
+func TestWorkspace_DataRetentionPolicy(t *testing.T) {
+	skipUnlessEnterprise(t)
+
+	client := testClient(t)
+	ctx := context.Background()
+
+	wTest, wTestCleanup := createWorkspace(t, client, nil)
+	defer wTestCleanup()
+
+	dataRetentionPolicy, err := client.Workspaces.ReadDataRetentionPolicyChoice(ctx, wTest.ID)
+	assert.Nil(t, err)
+	require.Nil(t, dataRetentionPolicy)
+
+	workspace, err := client.Workspaces.ReadByID(ctx, wTest.ID)
+	require.NoError(t, err)
+	require.Nil(t, workspace.DataRetentionPolicy)
+	require.Nil(t, workspace.DataRetentionPolicyChoice)
+
+	t.Run("set and update data retention policy to delete older", func(t *testing.T) {
+		createdDataRetentionPolicy, err := client.Workspaces.SetDataRetentionPolicyDeleteOlder(ctx, wTest.ID, DataRetentionPolicyDeleteOlderSetOptions{DeleteOlderThanNDays: 33})
+		require.NoError(t, err)
+		require.Equal(t, 33, createdDataRetentionPolicy.DeleteOlderThanNDays)
+		require.Contains(t, createdDataRetentionPolicy.ID, "drp-")
+
+		dataRetentionPolicy, err = client.Workspaces.ReadDataRetentionPolicyChoice(ctx, wTest.ID)
+		require.NoError(t, err)
+		require.NotNil(t, dataRetentionPolicy.DataRetentionPolicyDeleteOlder)
+
+		require.Equal(t, 33, dataRetentionPolicy.DataRetentionPolicyDeleteOlder.DeleteOlderThanNDays)
+		require.Equal(t, createdDataRetentionPolicy.ID, dataRetentionPolicy.DataRetentionPolicyDeleteOlder.ID)
+		require.Contains(t, dataRetentionPolicy.DataRetentionPolicyDeleteOlder.ID, "drp-")
+
+		workspace, err := client.Workspaces.ReadByID(ctx, wTest.ID)
+		require.NoError(t, err)
+		require.Equal(t, dataRetentionPolicy.DataRetentionPolicyDeleteOlder.ID, workspace.DataRetentionPolicyChoice.DataRetentionPolicyDeleteOlder.ID)
+
+		// deprecated DataRetentionPolicy field should also have been populated
+		require.NotNil(t, workspace.DataRetentionPolicy)
+		require.Equal(t, workspace.DataRetentionPolicy.ID, dataRetentionPolicy.DataRetentionPolicyDeleteOlder.ID)
+
+		// try updating the number of days
+		createdDataRetentionPolicy, err = client.Workspaces.SetDataRetentionPolicyDeleteOlder(ctx, wTest.ID, DataRetentionPolicyDeleteOlderSetOptions{DeleteOlderThanNDays: 1})
+		require.NoError(t, err)
+		require.Equal(t, 1, createdDataRetentionPolicy.DeleteOlderThanNDays)
+
+		dataRetentionPolicy, err = client.Workspaces.ReadDataRetentionPolicyChoice(ctx, wTest.ID)
+		require.NoError(t, err)
+		require.NotNil(t, dataRetentionPolicy.DataRetentionPolicyDeleteOlder)
+		require.Equal(t, 1, dataRetentionPolicy.DataRetentionPolicyDeleteOlder.DeleteOlderThanNDays)
+		require.Equal(t, createdDataRetentionPolicy.ID, dataRetentionPolicy.DataRetentionPolicyDeleteOlder.ID)
+	})
+
+	t.Run("set data retention policy to not delete", func(t *testing.T) {
+		createdDataRetentionPolicy, err := client.Workspaces.SetDataRetentionPolicyDontDelete(ctx, wTest.ID, DataRetentionPolicyDontDeleteSetOptions{})
+		require.NoError(t, err)
+		require.Contains(t, createdDataRetentionPolicy.ID, "drp-")
+
+		dataRetentionPolicy, err = client.Workspaces.ReadDataRetentionPolicyChoice(ctx, wTest.ID)
+		require.NoError(t, err)
+		require.NotNil(t, dataRetentionPolicy.DataRetentionPolicyDontDelete)
+		require.Equal(t, createdDataRetentionPolicy.ID, dataRetentionPolicy.DataRetentionPolicyDontDelete.ID)
+
+		// dont delete policies should leave the legacy DataRetentionPolicy field on workspaces empty
+		workspace, err := client.Workspaces.ReadByID(ctx, wTest.ID)
+		require.NoError(t, err)
+		require.Nil(t, workspace.DataRetentionPolicy)
+	})
+
+	t.Run("change data retention policy type", func(t *testing.T) {
+		_, err = client.Workspaces.SetDataRetentionPolicyDeleteOlder(ctx, wTest.ID, DataRetentionPolicyDeleteOlderSetOptions{DeleteOlderThanNDays: 45})
+		require.NoError(t, err)
+
+		dataRetentionPolicy, err = client.Workspaces.ReadDataRetentionPolicyChoice(ctx, wTest.ID)
+		require.NoError(t, err)
+		require.NotNil(t, dataRetentionPolicy.DataRetentionPolicyDeleteOlder)
+		require.Equal(t, 45, dataRetentionPolicy.DataRetentionPolicyDeleteOlder.DeleteOlderThanNDays)
+		require.Nil(t, dataRetentionPolicy.DataRetentionPolicyDontDelete)
+
+		_, err = client.Workspaces.SetDataRetentionPolicyDontDelete(ctx, wTest.ID, DataRetentionPolicyDontDeleteSetOptions{})
+		require.NoError(t, err)
+		dataRetentionPolicy, err = client.Workspaces.ReadDataRetentionPolicyChoice(ctx, wTest.ID)
+		require.NoError(t, err)
+		require.Nil(t, dataRetentionPolicy.DataRetentionPolicyDeleteOlder)
+		require.NotNil(t, dataRetentionPolicy.DataRetentionPolicyDontDelete)
+
+		_, err = client.Workspaces.SetDataRetentionPolicyDeleteOlder(ctx, wTest.ID, DataRetentionPolicyDeleteOlderSetOptions{DeleteOlderThanNDays: 20})
+		require.NoError(t, err)
+
+		dataRetentionPolicy, err = client.Workspaces.ReadDataRetentionPolicyChoice(ctx, wTest.ID)
+		require.NoError(t, err)
+		require.NotNil(t, dataRetentionPolicy.DataRetentionPolicyDeleteOlder)
+		require.Equal(t, 20, dataRetentionPolicy.DataRetentionPolicyDeleteOlder.DeleteOlderThanNDays)
+		require.Nil(t, dataRetentionPolicy.DataRetentionPolicyDontDelete)
+	})
+
+	t.Run("delete data retention policy", func(t *testing.T) {
+		err = client.Workspaces.DeleteDataRetentionPolicy(ctx, wTest.ID)
+		require.NoError(t, err)
+
+		dataRetentionPolicy, err = client.Workspaces.ReadDataRetentionPolicyChoice(ctx, wTest.ID)
+		assert.Nil(t, err)
+		require.Nil(t, dataRetentionPolicy)
+	})
+}
+
+func TestWorkspacesAutoDestroy(t *testing.T) {
+	client := testClient(t)
+	ctx := context.Background()
+
+	orgTest, orgTestCleanup := createOrganization(t, client)
+	t.Cleanup(orgTestCleanup)
+
+	upgradeOrganizationSubscription(t, client, orgTest)
+
+	autoDestroyAt := NullableTime(time.Date(2025, 1, 1, 0, 0, 0, 0, time.UTC))
+	wTest, wCleanup := createWorkspaceWithOptions(t, client, orgTest, WorkspaceCreateOptions{
+		Name:          String(randomString(t)),
+		AutoDestroyAt: autoDestroyAt,
+	})
+	t.Cleanup(wCleanup)
+
+	require.Equal(t, wTest.AutoDestroyAt, autoDestroyAt)
+
+	// respect default omitempty
+	w, err := client.Workspaces.Update(ctx, orgTest.Name, wTest.Name, WorkspaceUpdateOptions{
+		AutoDestroyAt: nil,
+	})
+
+	require.NoError(t, err)
+	require.NotNil(t, w.AutoDestroyAt)
+
+	// explicitly update the value of auto_destroy_at
+	w, err = client.Workspaces.Update(ctx, orgTest.Name, wTest.Name, WorkspaceUpdateOptions{
+		AutoDestroyAt: NullableTime(time.Date(2025, 1, 2, 0, 0, 0, 0, time.UTC)),
+	})
+
+	require.NoError(t, err)
+	require.NotNil(t, w.AutoDestroyAt)
+	require.NotEqual(t, w.AutoDestroyAt, autoDestroyAt)
+
+	// disable auto destroy
+	w, err = client.Workspaces.Update(ctx, orgTest.Name, wTest.Name, WorkspaceUpdateOptions{
+		AutoDestroyAt: NullTime(),
+	})
+
+	require.NoError(t, err)
+	require.Nil(t, w.AutoDestroyAt)
+}
